/*
	FreeRTOS V8.2.3  Copyright (C) 2016 WITTENSTEIN aerospace & simulation limited.

	This file is a contribution to the FreeRTOS product.

	WITTENSTEIN high integrity systems is a trading name of WITTENSTEIN
	aerospace & simulation ltd, Registered Office: Brown's Court, Long Ashton
	Business Park, Yanley Lane, Long Ashton, Bristol, BS41 9LB, UK.
	Tel: +44 (0) 1275 395 600, fax: +44 (0) 1275 393 630.
	E-mail: info@HighIntegritySystems.com

	http://www.HighIntegritySystems.com
*/

/*
 * "Reg test" tasks - These fill the registers with known values, then check
 * that each register maintains its expected value for the lifetime of the
 * task.  Each task uses a different set of values.  The reg test tasks execute
 * with a very low priority, so get preempted very frequently.  A register
 * containing an unexpected value is indicative of an error in the context
 * switching mechanism.
 */

void vRegTest1Task( void *pvParameters );
void vRegTest2Task( void *pvParameters );

void vRegTest1Task( void *pvParameters )
{
	( void ) pvParameters;

	__asm__ volatile
	(
		"	.globl	_uxRegTest1Value		\n"

		"# Fill the core registers with known values.\n"
		"	movw	$0x100, r0				\n"
		"	movw	$0x101, r1				\n"
		"	movw	$0x102, r2				\n"
		"	movw	$0x103, r3				\n"
		"	movw	$0x104, r4				\n"
		"	movw	$0x105, r5				\n"
		"	movw	$0x106, r6				\n"
		"	movw	$0x107, r7				\n"
		"	movw	$0x108, r8				\n"
		"	movw	$0x109, r9				\n"
		"	movw	$0x110, r10				\n"
		"	movw	$0x111, r11				\n"
		"	movd	$0x1121212, (r12)		\n"
		"	movd	$0x1131313, (r13)		\n"

		"reg1_loop:							\n"

		"# Check all the registers still contain the values set above.\n"
		"	cmpw	$0x100, r0				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpw	$0x101, r1				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpw	$0x102, r2				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpw	$0x103, r3				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpw	$0x104, r4				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpw	$0x105, r5				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpw	$0x106, r6				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpw	$0x107, r7				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpw	$0x108, r8				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpw	$0x109, r9				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpw	$0x110, r10				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpw	$0x111, r11				\n"
		"	bne		reg1_error_loop			\n"
		"	cmpd	$0x1121212, (r12)		\n"
		"	bne		reg2_error_loop			\n"
		"	cmpd	$0x1131313, (r13)		\n"
		"	bne		reg2_error_loop			\n"

		"# Increment the loop counter to indicate this test is still functioning correctly.\n"
		"	push 	$1, r0					\n"
		"	loadw	_uxRegTest1Value, r0	\n"
		"	addw 	$1, r0					\n"
		"	storw 	r0, _uxRegTest1Value	\n"
		"	pop 	$1, r0					\n"

		"# Start again.\n"
		"	br 		reg1_loop				\n"

		"reg1_error_loop:					\n"
		"# If this line is hit then there was an error in a core register value.\n"
		"# The loop ensures the loop counter stops incrementing.\n"
		"	br 		reg1_error_loop			\n"
		"	nop								"
	);
}
/*-----------------------------------------------------------*/

void vRegTest2Task( void *pvParameters )
{
	( void ) pvParameters;

	__asm__ volatile
	(
		"	.globl	_uxRegTest2Value 		\n"

		"# Set all the core registers to known values.\n"
		"	movw	$0x200, r0				\n"
		"	movw	$0x201, r1				\n"
		"	movw	$0x202, r2				\n"
		"	movw	$0x203, r3				\n"
		"	movw	$0x204, r4				\n"
		"	movw	$0x205, r5				\n"
		"	movw	$0x206, r6				\n"
		"	movw	$0x207, r7				\n"
		"	movw	$0x208, r8				\n"
		"	movw	$0x209, r9				\n"
		"	movw	$0x210, r10				\n"
		"	movw	$0x211, r11				\n"
		"	movd	$0x2121212, (r12)		\n"
		"	movd	$0x2131313, (r13)		\n"

		"reg2_loop:							\n"

		"# Check all the registers still contain the values set above.\n"
		"	cmpw	$0x200, r0				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpw	$0x201, r1				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpw	$0x202, r2				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpw	$0x203, r3				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpw	$0x204, r4				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpw	$0x205, r5				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpw	$0x206, r6				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpw	$0x207, r7				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpw	$0x208, r8				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpw	$0x209, r9				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpw	$0x210, r10				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpw	$0x211, r11				\n"
		"	bne		reg2_error_loop			\n"
		"	cmpd	$0x2121212, (r12)		\n"
		"	bne		reg2_error_loop			\n"
		"	cmpd	$0x2131313, (r13)		\n"
		"	bne		reg2_error_loop			\n"

		"# Increment the loop counter to indicate this test is still functioning correctly.\n"
		"	push 	$1, r0					\n"
		"	loadw	_uxRegTest2Value, r0	\n"
		"	addw 	$1, r0					\n"
		"	storw 	r0, _uxRegTest2Value	\n"
		"	pop 	$1, r0					\n"

		"# Start again.\n"
		"	br		reg2_loop				\n"

		"reg2_error_loop:					\n"
		"# If this line is hit then there was an error in a core register value.\n"
		"# This loop ensures the loop counter variable stops incrementing.\n"
		"	br		reg2_error_loop			\n"
		"	nop								"
	);
}
/*-----------------------------------------------------------*/

