#
#	FreeRTOS V8.2.3  Copyright (C) 2016 WITTENSTEIN aerospace & simulation limited.
#
#	This file is a contribution to the FreeRTOS product.
#
#	WITTENSTEIN high integrity systems is a trading name of WITTENSTEIN
#	aerospace & simulation ltd, Registered Office: Brown's Court, Long Ashton
#	Business Park, Yanley Lane, Long Ashton, Bristol, BS41 9LB, UK.
#	Tel: +44 (0) 1275 395 600, fax: +44 (0) 1275 393 630.
#	E-mail: info@HighIntegritySystems.com
#
#	http://www.HighIntegritySystems.com
#

	.text
	.align			2

	.globl 			_vFreeRTOSInterruptHandler
	.globl 			_vPortYield

	.globl 			_vPortIsrDispatcher
	.code_label		_vPortIsrDispatcher

	.globl			_vTaskSwitchContext
	.code_label		_vTaskSwitchContext

	.globl			_pxCurrentTCB
	.globl 			_xPortContextSwitch

#------------------------------------------------------------------------------

_vFreeRTOSInterruptHandler:
	# Save safe registers and return address.
	push	$8, r8, ra

	# Save scratch registers.
	push	$8, r0

	# Call dispatcher.
	bal		(ra), _vPortIsrDispatcher

	# Check if a context switch is required.
	loadw	_xPortContextSwitch, r1
	cmpw	$0, r1
	beq		restore_context

	# Clear xPortContextSwitch.
	storw	$0, _xPortContextSwitch

	# Get interrupt stack pointer.
	sprd	isp, (r12)

	# Save processor status.
	loadw	4(r12), r0
	push	$1, r0

	# Save return address.
	loadd	0(r12), (r1,r0)
	push	$2, r0

	# Save stack pointer.
	loadd	_pxCurrentTCB, (r1,r0)
	stord	(sp), 0(r1,r0)

	# Select next task.
	bal		(ra), _vTaskSwitchContext

	# Restore stack pointer.
	loadd	_pxCurrentTCB, (r1,r0)
	loadd	0(r1,r0), (sp)

	# Restore return address.
	pop		$2, r0
	stord	(r1,r0), 0(r12)

	# Restore processor status.
	pop		$1, r0
	storw	r0, 4(r12)

restore_context:
	# Restore scratch registers.
	pop		$8, r0

	# Restore safe registers and return address.
	pop		$8, r8, ra

	# Return from exception.
	retx
#------------------------------------------------------------------------------

_vPortYield:
	# Save safe registers and return address.
	push	$8, r8, ra

	# Save scratch registers.
	push	$8, r0

	# Get interrupt stack pointer.
	sprd	isp, (r12)

	# Save processor status.
	loadw	4(r12), r0
	push	$1, r0

	# Save return address (add 1 to return to the 1st instruction after EXCP).
	loadd	0(r12), (r1,r0)
	addd	$1, (r1,r0)
	push	$2, r0

	# Save stack pointer.
	loadd	_pxCurrentTCB, (r1,r0)
	stord	(sp), 0(r1,r0)

	# Select next task.
	bal		(ra), _vTaskSwitchContext

	# Restore stack pointer.
	loadd	_pxCurrentTCB, (r1,r0)
	loadd	0(r1,r0), (sp)

	# Restore return address.
	pop		$2, r0
	stord	(r1,r0), 0(r12)

	# Restore processor status.
	pop		$1, r0
	storw	r0, 4(r12)

	# Restore scratch registers.
	pop		$8, r0

	# Restore safe registers and return address.
	pop		$8, r8, ra

	# Return from exception.
	retx
#------------------------------------------------------------------------------

