/*
	FreeRTOS V8.2.3  Copyright (C) 2016 WITTENSTEIN aerospace & simulation limited.

	This file is a contribution to the FreeRTOS product.

	WITTENSTEIN high integrity systems is a trading name of WITTENSTEIN
	aerospace & simulation ltd, Registered Office: Brown's Court, Long Ashton
	Business Park, Yanley Lane, Long Ashton, Bristol, BS41 9LB, UK.
	Tel: +44 (0) 1275 395 600, fax: +44 (0) 1275 393 630.
	E-mail: info@HighIntegritySystems.com

	http://www.HighIntegritySystems.com
*/

#ifndef PORTMACRO_H
#define PORTMACRO_H

#ifdef __cplusplus
extern "C" {
#endif

/*-----------------------------------------------------------
 * Port specific definitions.
 *
 * The settings in this file configure FreeRTOS correctly for the
 * given hardware and compiler.
 *
 * These settings should not be altered.
 *-----------------------------------------------------------
 */

/* Type definitions. */
#define portCHAR		char
#define portFLOAT		float
#define portDOUBLE		double
#define portLONG		long
#define portSHORT		short
#define portSTACK_TYPE	uint16_t
#define portBASE_TYPE	long

typedef portSTACK_TYPE StackType_t;
typedef int16_t BaseType_t;
typedef uint16_t UBaseType_t;

#if( configUSE_16_BIT_TICKS == 1 )
	typedef uint16_t TickType_t;
	#define portMAX_DELAY ( TickType_t ) 0xFFFF
#define portTICK_TYPE_IS_ATOMIC	1
#else
	typedef uint32_t TickType_t;
	#define portMAX_DELAY ( TickType_t ) 0xFFFFFFFFUL

	/* 32-bit tick type on a 32-bit architecture, so reads of the tick count do
	not need to be guarded with a critical section. */
	#define portTICK_TYPE_IS_ATOMIC	0
#endif
/*-----------------------------------------------------------*/

/* Architecture specifics. */
#define portSTACK_GROWTH				( -1 )
#define portTICK_PERIOD_MS				( ( TickType_t ) 1000 / configTICK_RATE_HZ )
#define portBYTE_ALIGNMENT				2
#define portNOP()                   	__asm__ volatile ( "NOP" )
#define portCRITICAL_NESTING_IN_TCB		1
/*-----------------------------------------------------------*/


extern volatile BaseType_t xPortContextSwitch;
extern void vTaskSwitchContext( void );

#define portYIELD()					\
{									\
	portENTER_CRITICAL();			\
	__asm__ volatile ( "excp svc" );\
	portEXIT_CRITICAL();			\
}

#define portEND_SWITCHING_ISR( xSwitchRequired )	\
	if( xSwitchRequired )							\
	{												\
		xPortContextSwitch = pdTRUE;				\
	}


/*-----------------------------------------------------------*/

extern void vTaskEnterCritical( void );
extern void vTaskExitCritical( void );
#define portENTER_CRITICAL()	vTaskEnterCritical()
#define portEXIT_CRITICAL()		vTaskExitCritical()

#define portDISABLE_INTERRUPTS()	__asm__ volatile ( "di" )
#define portENABLE_INTERRUPTS()		__asm__ volatile ( "ei" )
/*-----------------------------------------------------------*/

/* Interrupt Dispatch table. */
#define portICU_TRAP_NUM		( 16U )
#define portICU_INTERRUPT_NUM	( 32U )

typedef void ( *PortISR_t )( void );

extern PortISR_t axFreeRTOSIsrSwDispatchTable[ portICU_INTERRUPT_NUM ];
/*-----------------------------------------------------------*/

/* Task function macros as described on the FreeRTOS.org WEB site. */
#define portTASK_FUNCTION_PROTO( vFunction, pvParameters ) void vFunction( void *pvParameters )
#define portTASK_FUNCTION( vFunction, pvParameters ) void vFunction( void *pvParameters )

/*-----------------------------------------------------------*/

#ifdef __cplusplus
}
#endif

#endif /* PORTMACRO_H */

