/*---------------------------------------------------------------------------------------------------------*/
/*  Nuvoton Technology Corporation confidential                                                            */
/*                                                                                                         */
/*  Copyright (c) 2010 by Nuvoton Technology Corporation                                                   */
/*  All rights reserved                                                                                    */
/*                                                                                                         */
/*<<<------------------------------------------------------------------------------------------------------*/
/* File Contents:                                                                                          */
/*   npce9mnx.h                                                                                            */
/*            This file contains chip definitions for the given project                                    */
/*  Project:                                                                                               */
/*            SWC HAL                                                                                      */
/*---------------------------------------------------------------------------------------------------------*/

#ifndef __NPCE9MNX_CHIP_H__
#define __NPCE9MNX_CHIP_H__

/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                              CHIP                                                       */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/* Chip Name                                                                                               */
/*---------------------------------------------------------------------------------------------------------*/
#define NPCE9MNX


/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                              MEMORIES                                                   */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/* ROM                                                                                                     */
/*---------------------------------------------------------------------------------------------------------*/
#define ROM_BASE_ADDR                       0x00000000
#define ROM_MEMORY_SIZE                     _4KB_

/*---------------------------------------------------------------------------------------------------------*/
/* On-Chip SRAM                                                                                            */
/*---------------------------------------------------------------------------------------------------------*/
#define RAM_BASE_ADDR                       0x00010000
#define RAM_MEMORY_SIZE                     _4KB_

/*---------------------------------------------------------------------------------------------------------*/
/* SPI Flash                                                                                               */
/*---------------------------------------------------------------------------------------------------------*/
#define FLASH_BASE_ADDR(device)             0x00080000
#define FLASH_MEMORY_SIZE(device)           _256KB_
#define FLASH_NUM_OF_DEVICES                1


/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                               CLOCKS                                                    */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/* Frequency Multiplier Clock Frequency                                                                    */
/*---------------------------------------------------------------------------------------------------------*/
#define HFCG_FMCLK                          50000000

/*---------------------------------------------------------------------------------------------------------*/
/* Flash Clock Frequency                                                                                   */
/*---------------------------------------------------------------------------------------------------------*/
#define HFCG_FLASH_CLK                      50000000

/*---------------------------------------------------------------------------------------------------------*/
/* Core Clock Frequency                                                                                    */
/*---------------------------------------------------------------------------------------------------------*/
#define HFCG_CORE_CLK                       50000000

/*---------------------------------------------------------------------------------------------------------*/
/* Core Clock Low Frequency                                                                                */
/*---------------------------------------------------------------------------------------------------------*/
#define LFCG_CORE_CLK                       32768

/*---------------------------------------------------------------------------------------------------------*/
/* Number of cycles per iteration                                                                          */
/*---------------------------------------------------------------------------------------------------------*/
#define HFCG_NUM_OF_CYCLES_PER_ITERATION    17

/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                              MODULE DRIVERS                                             */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/* Chip System Configuration                                                                               */
/*---------------------------------------------------------------------------------------------------------*/
#define CHIP_CFG_ACCESS                     MEM
#define CHIP_CFG_BASE_ADDR                  0xFFF000

/*---------------------------------------------------------------------------------------------------------*/
/* Interrupt Control Unit Module                                                                           */
/*---------------------------------------------------------------------------------------------------------*/
#define ICU_MODULE_TYPE                     1
#define ICU_ACCESS                          MEM
#define ICU_BASE_ADDR                       0xFFFE00
#define ICU_TRAP_NUM                        16
#define ICU_INTERRUPT_NUM                   32

/*---------------------------------------------------------------------------------------------------------*/
/* System Management Bus Module                                                                            */
/*---------------------------------------------------------------------------------------------------------*/
#define SMB_MODULE_TYPE                     1
#define SMB_ACCESS                          MEM
#define SMB_BASE_ADDR(module)               (0xFFF500 + ((module) * 0x40L))
#define SMB_INTERRUPT(module)               CHIP_SMB_INT(module)
#define SMB_INTERRUPT_POLARITY              INTERRUPT_POLARITY_RISING_EDGE
#define SMB_INTERRUPT_PRIORITY              0
#define SMB_INTERRUPT_PROVIDER              INTERRUPT_PROVIDER_ICU
#define SMB_NUM_OF_MODULES                  5
#define SMB_MODULE_FIFO                     SMB_MODULE_5
#define SMB_SOURCE_CLOCK(module)            HFCG_CORE_CLK
#define SMB_MUX(module)                     CHIP_MuxSMB(module)

/*---------------------------------------------------------------------------------------------------------*/
/* System Glue Module                                                                                      */
/*---------------------------------------------------------------------------------------------------------*/
#define GLUE_ACCESS                         MEM
#define GLUE_BASE_ADDR                      0xFFF6C0

/*---------------------------------------------------------------------------------------------------------*/
/* High Frequency Clock Generator Module                                                                   */
/*---------------------------------------------------------------------------------------------------------*/
#define HFCG_MODULE_TYPE                    2
#define HFCG_ACCESS                         MEM
#define HFCG_BASE_ADDR                      0xFFF080

/*---------------------------------------------------------------------------------------------------------*/
/* Timer Watch-Dog Module                                                                                  */
/*---------------------------------------------------------------------------------------------------------*/
#define TWD_MODULE_TYPE                     2
#define TWD_ACCESS                          MEM
#define TWD_BASE_ADDR                       0xFFF4C0
#define TWD_INTERRUPT                       ICU_INT_31
#define TWD_INTERRUPT_PROVIDER              INTERRUPT_PROVIDER_ICU
#define TWD_INTERRUPT_POLARITY              INTERRUPT_POLARITY_RISING_EDGE
#define TWD_INTERRUPT_PRIORITY              0
#define TWD_SOURCE_CLOCK                    LFCG_CORE_CLK

/*---------------------------------------------------------------------------------------------------------*/
/* Multi Input Wake-Up Module                                                                              */
/*---------------------------------------------------------------------------------------------------------*/
#define MIWU_MODULE_TYPE                    2
#define MIWU_ACCESS                         MEM
#define MIWU_BASE_ADDR(block)               0xFFF1C0
#define MIWU_NUM_OF_PORTS                   10
#define MIWU_NUM_OF_BLOCKS                  1
#define MIWU_INTERRUPT_PROVIDER             INTERRUPT_PROVIDER_ICU
#define MIWU_INTERRUPT_POLARITY             INTERRUPT_POLARITY_RISING_EDGE
#define MIWU_INTERRUPT_PRIORITY             0

/*---------------------------------------------------------------------------------------------------------*/
/* General Purpose I/O Module                                                                              */
/*---------------------------------------------------------------------------------------------------------*/
#define GPIO_MODULE_TYPE                    2
#define GPIO_ACCESS                         MEM
#define GPIO_BASE_ADDR(module)              (0xFFF200 + ((module) * 0x10L))
#define GPIO_NUM_OF_PORTS                   16
#define GPIO_MUX(gpio)                      CHIP_MuxGPIO(gpio)
#define GPIO_MUX_PORT(port)                 CHIP_MuxGPIOPort(port)

/*---------------------------------------------------------------------------------------------------------*/
/* Mobile System Wake-up Control Module                                                                    */
/*---------------------------------------------------------------------------------------------------------*/
#define MSWC_MODULE_TYPE                    1
#define MSWC_ACCESS                         MEM
#define MSWC_HOST_ACCESS                    SIB
#define MSWC_BASE_ADDR                      0xFFF040
#define MSWC_INTERRUPT                      MIWU_MSWC
#define MSWC_INTERRUPT_POLARITY             INTERRUPT_POLARITY_RISING_EDGE
#define MSWC_INTERRUPT_PRIORITY             0
#define MSWC_INTERRUPT_PROVIDER             INTERRUPT_PROVIDER_MIWU

/*---------------------------------------------------------------------------------------------------------*/
/* SuperI/O Internal Bus Module                                                                            */
/*---------------------------------------------------------------------------------------------------------*/
#define SIB_MODULE_TYPE                     1
#define SIB_ACCESS                          MEM
#define SIB_BASE_ADDR                       0xFFF740

/*---------------------------------------------------------------------------------------------------------*/
/* SuperI/O Configuration Module                                                                           */
/*---------------------------------------------------------------------------------------------------------*/
#define SIO_MODULE_TYPE                     1
#define SIO_ACCESS                          SIB

/*---------------------------------------------------------------------------------------------------------*/
/* PS2 Module                                                                                              */
/*---------------------------------------------------------------------------------------------------------*/
#define PS2_MODULE_TYPE                     1
#define PS2_ACCESS                          MEM
#define PS2_BASE_ADDR                       0xFFF300
#define PS2_NUM_OF_CHANNELS                 3
#define PS2_INTERRUPT                       ICU_INT_21
#define PS2_INTERRUPT_POLARITY              INTERRUPT_POLARITY_RISING_EDGE
#define PS2_INTERRUPT_PRIORITY              0
#define PS2_INTERRUPT_PROVIDER              INTERRUPT_PROVIDER_ICU

/*---------------------------------------------------------------------------------------------------------*/
/* Multi-Function Timer Module                                                                             */
/*---------------------------------------------------------------------------------------------------------*/
#define MFT_MODULE_TYPE                     1
#define MFT_ACCESS                          MEM
#define MFT_BASE_ADDR(module)               (0xFFF340 + ((module) * 0x40L))
#define MFT_INTERRUPT(module)               ((module) == 0 ? ICU_INT_9 :        \
                                             (module) == 1 ? ICU_INT_23 :       \
                                                             ICU_INT_17)
#define MFT_INTERRUPT_POLARITY              INTERRUPT_POLARITY_RISING_EDGE
#define MFT_INTERRUPT_PRIORITY              0
#define MFT_INTERRUPT_PROVIDER              INTERRUPT_PROVIDER_ICU
#define MFT_NUM_OF_MODULES                  3
#define MFT_PRESCALER_CLOCK                 HFCG_CORE_CLK
#define MFT_MUX(module, timer)              CHIP_MuxMFT(module, timer)

/*---------------------------------------------------------------------------------------------------------*/
/* INTERNAL 8-BIT TIMER (ITIM8)                                                                            */
/*---------------------------------------------------------------------------------------------------------*/
#define ITIM8_MODULE_TYPE                   2
#define ITIM8_ACCESS                        MEM
#define ITIM8_BASE_ADDR(module)             (0xFFF700 + ((module) * 0x10L))
#define ITIM8_NUM_OF_MODULES                3
#define ITIM8_INTERRUPT(module)             ((module == 0) ? ICU_INT_28 :                      \
                                            ((module == 1) ? ICU_INT_27 :                      \
                                                             ICU_INT_17))
#define ITIM8_INTERRUPT_POLARITY(module)    INTERRUPT_POLARITY_RISING_EDGE
#define ITIM8_INTERRUPT_PRIORITY(module)    0
#define ITIM8_INTERRUPT_PROVIDER(module)    INTERRUPT_PROVIDER_ICU
#define ITIM8_SOURCE_CLOCK(source)          ((source == ITIM8_SOURCE_CLOCK_1) ? HFCG_CORE_CLK : LFCG_CORE_CLK)

#define ITIM8_SOURCE_CLOCK_CORE             ITIM8_SOURCE_CLOCK_1
#define ITIM8_SOURCE_CLOCK_32K              ITIM8_SOURCE_CLOCK_2

/*---------------------------------------------------------------------------------------------------------*/
/* Pulse-Width Modulator Module                                                                            */
/*---------------------------------------------------------------------------------------------------------*/
#define PWM_MODULE_TYPE                     1
#define PWM_ACCESS                          MEM
#define PWM_BASE_ADDR(module)               (0xFFF440 + ((module) * 0x10L))
#define PWM_NUM_OF_MODULES                  8
#define PWM_SOURCE_CLOCK(source)            ((source == PWM_SOURCE_CLOCK_1) ? HFCG_CORE_CLK : LFCG_CORE_CLK)
#define PWM_MUX(module)                     CHIP_MuxPWM(module)

#define PWM_SOURCE_CLOCK_CORE               PWM_SOURCE_CLOCK_1
#define PWM_SOURCE_CLOCK_32K                PWM_SOURCE_CLOCK_2

/*---------------------------------------------------------------------------------------------------------*/
/* Analog-to-Digital Converter Module                                                                      */
/*---------------------------------------------------------------------------------------------------------*/
#define ADC_MODULE_TYPE                     2
#define ADC_ACCESS                          MEM
#define ADC_BASE_ADDR                       0xFFF800
#define ADC_INTERRUPT                       ICU_INT_10
#define ADC_INTERRUPT_POLARITY              INTERRUPT_POLARITY_RISING_EDGE
#define ADC_INTERRUPT_PRIORITY              0
#define ADC_INTERRUPT_PROVIDER              INTERRUPT_PROVIDER_ICU
#define ADC_NUM_OF_INPUTS                   13
#define ADC_CLK                             2000000
#define ADC_SOURCE_CLOCK                    HFCG_CORE_CLK
#define ADC_MUX(input)                      CHIP_MuxADC(input)

/*---------------------------------------------------------------------------------------------------------*/
/* Digital-to-Analog Converter Module                                                                      */
/*---------------------------------------------------------------------------------------------------------*/
#define DAC_MODULE_TYPE                     1
#define DAC_ACCESS                          MEM
#define DAC_BASE_ADDR                       0xFFF880
#define DAC_NUM_OF_INPUTS                   4
#define DAC_MUX(input)                      CHIP_MuxDAC(input)

/*---------------------------------------------------------------------------------------------------------*/
/* Platform Environment Control Interface Module                                                           */
/*---------------------------------------------------------------------------------------------------------*/
#define PECI_MODULE_TYPE                    1
#define PECI_ACCESS                         MEM
#define PECI_BASE_ADDR                      0xFFF900
#define PECI_INTERRUPT                      ICU_INT_6
#define PECI_INTERRUPT_POLARITY             INTERRUPT_POLARITY_RISING_EDGE
#define PECI_INTERRUPT_PRIORITY             0
#define PECI_INTERRUPT_PROVIDER             INTERRUPT_PROVIDER_ICU
#define PECI_SOURCE_CLOCK                   HFCG_FMCLK
#define PECI_MUX()                          CHIP_MuxPECI()

/*---------------------------------------------------------------------------------------------------------*/
/* Peripheral SPI Module                                                                                   */
/*---------------------------------------------------------------------------------------------------------*/
#define SPI_MODULE_TYPE                     1
#define SPI_ACCESS                          MEM
#define SPI_BASE_ADDR(module)               0xFFF0C0
#define SPI_INTERRUPT                       ICU_INT_12
#define SPI_NUM_OF_MODULES                  1
#define SPI_SOURCE_CLOCK                    HFCG_CORE_CLK
#define SPI_MUX(module)                     CHIP_MuxSPI(module)

/*---------------------------------------------------------------------------------------------------------*/
/* Power Management Controller Module                                                                      */
/*---------------------------------------------------------------------------------------------------------*/
#define PMC_MODULE_TYPE                     2
#define PMC_ACCESS                          MEM
#define PMC_BASE_ADDR                       0xFFF100

/*---------------------------------------------------------------------------------------------------------*/
/* Internal keyboard scan                                                                                  */
/*---------------------------------------------------------------------------------------------------------*/
#define KBSCAN_MODULE_TYPE                  1
#define KBSCAN_ACCESS                       MEM
#define KBSCAN_REGS_BASE                    0xFFF6C0
#define KBSCAN_INTERRUPT                    ICU_INT_15
#define KBSCAN_NUM_OF_OUTPUTS               18
#define KBSCAN_NUM_OF_INPUTS                8
#define KBSCAN_MIWU_PORT                    3
#define KBSCAN_MUX()                        DEFS_STATUS_OK

/*---------------------------------------------------------------------------------------------------------*/
/* Flash Interface Unit Module                                                                             */
/*---------------------------------------------------------------------------------------------------------*/
#define FIU_MODULE_TYPE                     4
#define FIU_ACCESS                          MEM
#define FIU_BASE_ADDR                       0x0F0000

/*---------------------------------------------------------------------------------------------------------*/
/* Power Management Channels Module                                                                        */
/*---------------------------------------------------------------------------------------------------------*/
#define PM_CHAN_MODULE_TYPE                 2
#define PM_CHAN_ACCESS                      MEM
#define PM_CHAN_HOST_ACCESS                 SIB
#define PM_CHAN_NUM_OF_CHANNELS             4
#define PM_CHAN_BASE_ADDR(module)           ((module) == 0 ? 0xFFF78C :       \
                                             (module) == 1 ? 0xFFF79E :       \
                                             (module) == 2 ? 0xFFF7C0 :       \
                                                             0xFFF7D2)
#define PM_CHAN_INTERRUPT_OBE               ICU_INT_3
#define PM_CHAN_INTERRUPT_IBF               ICU_INT_26

/*---------------------------------------------------------------------------------------------------------*/
/* Shared Memory Module                                                                                    */
/*---------------------------------------------------------------------------------------------------------*/
#define SHM_MODULE_TYPE                     1
#define SHM_ACCESS                          MEM
#define SHM_BASE_ADDR                       0xFF0400
#define SHM_INTERRUPT                       ICU_INT_24
#define SHM_INTERRUPT_POLARITY              INTERRUPT_POLARITY_RISING_EDGE
#define SHM_INTERRUPT_PRIORITY              0
#define SHM_INTERRUPT_PROVIDER              INTERRUPT_PROVIDER_ICU
#define SHM_NUM_OF_WINDOWS                  4
#define SHM_RAM_BASE_ADDR                   RAM_BASE_ADDR


/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                             Logical Devices                                             */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
typedef enum
{
    LDN_MSWC            = 0x04,
    LDN_KBC_MOUSE       = 0x05,
    LDN_KBC_KEYBOARD    = 0x06,
    LDN_GPIO            = 0x07,
    LDN_SHM             = 0x0F,
    LDN_PM1             = 0x11,
    LDN_PM2             = 0x12,
    LDN_PM3             = 0x17,
    LDN_ESHM            = 0x1D,
    LDN_PM4             = 0x1E
} LDN_T;


/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                              TABLES                                                     */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/* MIWU Wake-Up Input Sources                                                                              */
/*---------------------------------------------------------------------------------------------------------*/
typedef enum {
    MIWU_MSWC = 0,      /* MSWC (MSWCI)                                                                    */
    MIWU_TWD,           /* TWD system tick (T0OUT)                                                         */
    MIWU_GPIO01,        /* GPIO01                                                                          */
    MIWU_GPIO21,        /* GPIO21                                                                          */
    MIWU_GPIO64,        /* GPIO64                                                                          */
    MIWU_GPIO90,        /* GPIO90                                                                          */
    MIWU_GPIO91,        /* GPIO91                                                                          */
    MIWU_GPIO94,        /* GPIO94                                                                          */
    MIWU_SMB1,          /* SMBus1                                                                          */
    MIWU_SMB2,          /* SMBus2                                                                          */
    MIWU_SMB3,          /* SMBus3                                                                          */
    MIWU_SMB4,          /* SMBus4                                                                          */
    MIWU_HACC,          /* Host Access                                                                     */
    MIWU_LRESET,        /* LRESET Transition                                                               */
    MIWU_PWBTIN,        /* Power Button GPIO01                                                             */
    MIWU_TB1,           /* MFT TB1                                                                         */
    MIWU_TB2,           /* MFT TB2                                                                         */
    MIWU_TB3,           /* MFT TB3                                                                         */
    MIWU_TA1,           /* MFT TA1                                                                         */
    MIWU_TA2,           /* MFT TA2                                                                         */
    MIWU_TA3,           /* MFT TA3                                                                         */
    MIWU_GPI06,         /* GPI06                                                                           */
    MIWU_LAST
} MIWU_SRC_T;

/*---------------------------------------------------------------------------------------------------------*/
/* MIWU Input Source Definition Table                                                                      */
/*---------------------------------------------------------------------------------------------------------*/
#define MIWU_DEFINITION_TABLE                                   \
{                                                               \
    { 0 , 0x26, ICU_INT_16},        /* MIWU_MSWC        */          \
    { 0 , 0x27, ICU_INT_31},        /* MIWU_TWD         */          \
    { 0 , 0x21, ICU_INT_30},        /* MIWU_GPIO01      */       \
    { 0 , 0x92, ICU_INT_15},        /* MIWU_GPIO21      */       \
    { 0 , 0x30, ICU_INT_15},        /* MIWU_GPIO64      */       \
    { 0 , 0x73, ICU_INT_11},        /* MIWU_GPIO90      */       \
    { 0 , 0x74, ICU_INT_11},        /* MIWU_GPIO91      */       \
    { 0 , 0x77, ICU_INT_11},        /* MIWU_GPIO94      */       \
    { 0 , 0x43, ICU_INT_7},         /* MIWU_SMB1        */          \
    { 0 , 0x44, ICU_INT_7},         /* MIWU_SMB2        */          \
    { 0 , 0x43, ICU_INT_7},         /* MIWU_SMB3        */          \
    { 0 , 0x44, ICU_INT_7},         /* MIWU_SMB4        */          \
    { 0 , 0x56, ICU_INT_11},        /* MIWU_HACC        */          \
    { 0 , 0x57, ICU_INT_11},        /* MIWU_LRESET      */          \
    { 0 , 0x21, ICU_INT_30},        /* MIWU_PWBTIN      */          \
    { 0 , 0x52, ICU_INT_11},        /* MIWU_TB1         */          \
    { 0 , 0x21, ICU_INT_30},        /* MIWU_TB2         */          \
    { 0 , 0x83, ICU_INT_11},        /* MIWU_TB3         */          \
    { 0 , 0x67, ICU_INT_11},        /* MIWU_TA1         */          \
    { 0 , 0x63, ICU_INT_11},        /* MIWU_TA2         */          \
    { 0 , 0x65, ICU_INT_11},        /* MIWU_TA3         */          \
    { 0 , 0x40, ICU_INT_7}          /* GPI06            */          \
}

/*---------------------------------------------------------------------------------------------------------*/
/* MIWU Port Definition Table                                                                              */
/*---------------------------------------------------------------------------------------------------------*/
#define MIWU_PORT_DEFINITION_TABLE                              \
{                                                               \
    ICU_INT_7,                  /* PORT 1      */               \
    ICU_INT_UNDEF,              /* PORT 2      */               \
    ICU_INT_15,                 /* PORT 3      */               \
    ICU_INT_7,                  /* PORT 4      */               \
    ICU_INT_11,                 /* PORT 5      */               \
    ICU_INT_11,                 /* PORT 6      */               \
    ICU_INT_11,                 /* PORT 7      */               \
    ICU_INT_11,                 /* PORT 8      */               \
    ICU_INT_15,                 /* PORT 9      */               \
    ICU_INT_15,                 /* PORT 10     */               \
}

/*---------------------------------------------------------------------------------------------------------*/
/* SIB Devices Definition Table                                                                            */
/*---------------------------------------------------------------------------------------------------------*/
#define SIB_DEFINITION_TABLE                                    \
{                                                               \
    MASK_BIT(0),    /* SIB_CFG_DEV      */                      \
              0,    /* SIB_SWC_DEV      */                      \
              0,    /* SIB_SP3_DEV      */                      \
              0,    /* SIB_SSL_DEV      */                      \
              0,    /* SIB_SP_DEV       */                      \
    MASK_BIT(7),    /* SIB_HGPIO_DEV    */                      \
              0,    /* SIB_CIRP_DEV     */                      \
    MASK_BIT(8),    /* SIB_MSWC_DEV     */                      \
              0,    /* SIB_EWOC_DEV     */                      \
    MASK_BIT(10),   /* SIB_SMEM_DEV     */                      \
    MASK_BIT(11),   /* SIB_HIKBD_DEV    */                      \
              0,    /* SIB_MBI_DEV      */                      \
    MASK_BIT(12),   /* SIB_PM1_DEV      */                      \
    MASK_BIT(13),   /* SIB_PM2_DEV      */                      \
    MASK_BIT(14),   /* SIB_PM3_DEV      */                      \
    MASK_BIT(15),   /* SIB_PM4_DEV      */                      \
    MASK_BIT(3),    /* SIB_ESHM_DEV     */                      \
}

/*---------------------------------------------------------------------------------------------------------*/
/* Logical Device Numbers Table                                                                            */
/*---------------------------------------------------------------------------------------------------------*/
#define LDN_DEFINITION_TABLE                                    \
{                                                               \
    { LDN_MSWC,         SIB_MSWC_DEV  },                        \
    { LDN_KBC_MOUSE,    SIB_HIKBD_DEV },                        \
    { LDN_KBC_KEYBOARD, SIB_HIKBD_DEV },                        \
    { LDN_GPIO,         SIB_HGPIO_DEV },                        \
    { LDN_SHM,          SIB_SMEM_DEV  },                        \
    { LDN_PM1,          SIB_PM1_DEV   },                        \
    { LDN_PM2,          SIB_PM2_DEV   },                        \
    { LDN_PM3,          SIB_PM3_DEV   },                        \
    { LDN_ESHM,         SIB_ESHM_DEV  },                        \
    { LDN_PM4,          SIB_PM4_DEV   },                        \
}

#endif  // __NPCE9MNX_CHIP_H__

