/*---------------------------------------------------------------------------------------------------------*/
/*  Nuvoton Technology Corporation confidential                                                            */
/*                                                                                                         */
/*  Copyright (c) 2009 by Nuvoton Technology Corporation                                                   */
/*  All rights reserved                                                                                    */
/*                                                                                                         */
/*<<<------------------------------------------------------------------------------------------------------*/
/* File Contents:                                                                                          */
/*   npce9mnx_if.h                                                                                         */
/*            This file contains chip dependent interface                                                  */
/* Project:                                                                                                */
/*            SWC_HAL                                                                                      */
/*---------------------------------------------------------------------------------------------------------*/

#ifndef __NPCE9MNX_IF_H__
#define __NPCE9MNX_IF_H__

/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                                 INCLUDES                                                */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
#include "../chip.h"

/*---------------------------------------------------------------------------------------------------------*/
/* Module Dependencies                                                                                     */
/*---------------------------------------------------------------------------------------------------------*/

#if defined (SMB_MODULE_TYPE)
#include __MODULE_IF_HEADER_FROM_CHIP_DRV(smb)
#endif

#if defined ICU_MODULE_TYPE
#include __MODULE_IF_HEADER_FROM_CHIP_DRV(icu)
#endif

#if defined (ADC_MODULE_TYPE)
#include __MODULE_IF_HEADER_FROM_CHIP_DRV(adc)
#endif

#if defined (PWM_MODULE_TYPE)
#include __MODULE_IF_HEADER_FROM_CHIP_DRV(pwm)
#endif

#if defined (SPI_MODULE_TYPE)
#include __MODULE_IF_HEADER_FROM_CHIP_DRV(spi)
#endif

#if defined (MFT_MODULE_TYPE)
#include __MODULE_IF_HEADER_FROM_CHIP_DRV(mft)
#endif

#if defined (DAC_MODULE_TYPE)
#include __MODULE_IF_HEADER_FROM_CHIP_DRV(dac)
#endif

#if defined (PS2_MODULE_TYPE)
#include __MODULE_IF_HEADER_FROM_CHIP_DRV(ps2)
#endif

#if defined (GPIO_MODULE_TYPE)
#include __MODULE_IF_HEADER_FROM_CHIP_DRV(gpio)
#endif



/*---------------------------------------------------------------------------------------------------------*/
/* SMBF MUX options                                                                                        */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (SMB_MODULE_TYPE)
typedef enum {
    SMBF_MUX_NONE  = 0,
    SMBF_MUX_1,
    SMBF_MUX_2,
    SMBF_MUX_3A    = 4,
    SMBF_MUX_3B,
    SMBF_MUX_4A,
    SMBF_MUX_4B
} SMBF_MUX_T;

#endif


/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                           INTERFACE FUNCTIONS                                           */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_SMB_INT                                                                           */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  smb_module - SMB Module number                                                         */
/*                                                                                                         */
/* Returns:         The resperctive Interrupt number of the given SMB module.                              */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine retrieves the interrupt number of the corresponding SMB module.           */
/*---------------------------------------------------------------------------------------------------------*/
#if  ( defined SMB_MODULE_TYPE) && ( defined ICU_MODULE_TYPE)
ICU_INT_SRC_T CHIP_SMB_INT(SMB_MODULE_T module);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_SMB_LowVoltageConfig                                                              */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  smb_module - SMB Module number                                                         */
/*                  enable  -    TRUE - Enable, FALSE - Disable                                            */
/*                                                                                                         */
/* Returns:                                                                                                */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine enable (or disables) the selected SMBus low voltage (1.8V) support.       */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (SMB_MODULE_TYPE)
void CHIP_SMB_LowVoltageConfig(SMB_MODULE_T smb_module, BOOLEAN enable);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_SMB_Configure                                                                     */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  Smb1_enable  -    Enable SMB1                                                          */
/*                  Smb2_enable  -    Enable SMB2                                                          */
/*                  Smb3A_enable -    Enable SMB3A                                                         */
/*                  Smb3B_enable -    Enable SMB3B                                                         */
/*                  Smb4A_enable -    Enable SMB4A                                                         */
/*                  Smb4B_enable -    Enable SMB4B                                                         */
/*                  SmbF_mux     -    SMBF MUX select                                                      */
/*                                                                                                         */
/* Returns:                                                                                                */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine selects the SMBx function to the corresponding pin.                       */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (SMB_MODULE_TYPE)
BOOLEAN CHIP_SMB_Configure (
    BOOLEAN Smb1_enable,
    BOOLEAN Smb2_enable,
    BOOLEAN Smb3A_enable,
    BOOLEAN Smb3B_enable,
    BOOLEAN Smb4A_enable,
    BOOLEAN Smb4B_enable,
    SMBF_MUX_T SmbF_mux
);
#endif


/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_MuxSMB                                                                            */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  smb_module - SMB Module number                                                         */
/*                                                                                                         */
/* Returns:         TRUE  - if this SBMBus was configured via CHIP_SMB_Configure()                         */
/*                  FALSE - otherwise                                                                      */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine checks if the selected SMBx was configured by CHIP_SMB_Configure()        */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (SMB_MODULE_TYPE)
BOOLEAN CHIP_MuxSMB (SMB_MODULE_T smb_module);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_GPIO_LowVoltageConfig                                                                           */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  gpio - GPIO number to mux                                                              */
/*                  enable  -    TRUE - Enable, FALSE - Disable                                            */
/*                                                                                                         */
/* Returns:                                                                                                */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine enable (or disables) the selected GPIO low voltage (1.8V) support.        */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (GPIO_MODULE_TYPE)
void CHIP_GPIO_LowVoltageConfig (UINT8 gpio, BOOLEAN enable);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_MuxGPIO                                                                           */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  gpio - GPIO number to mux                                                              */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine mux chip pin to function as GPIO                                          */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (GPIO_MODULE_TYPE)
void CHIP_MuxGPIO (UINT8 gpio);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_MuxGPIOPort                                                                       */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  port      - GPIO port number.                                                          */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine mux chip pins to function as port GPIOs                                   */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (GPIO_MODULE_TYPE)
void CHIP_MuxGPIOPort (UINT8 port);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_MuxMFT                                                                            */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  mft_module - The MFT module to be selected.                                            */
/*                  mft_timer -  The MFT timer to be selected.                                             */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine selects the TXn function to the corresponding pin, where:                 */
/*                   'X' is the MFT timer number  (A/B).                                                  */
/*                   'n' is the MFT module number (1/2/etc').                                             */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (MFT_MODULE_TYPE)
void CHIP_MuxMFT (MFT_MODULE_T mft_module, MFT_TIMER_T  mft_timer);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_MuxPS2                                                                            */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  ps2_channel - PS2 channel number                                                       */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine selects the PS2 channel interface on multiplexed pin.                     */
/*                  The function should be called prior to any PS2 operation.                              */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (PS2_MODULE_TYPE)
void CHIP_MuxPS2 (PS2_CHANNEL_T ps2_channel);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_MuxPWM                                                                            */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  pwm_module - The PWM module to be selected.                                            */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine selects the PWMx function to the corresponding pin.                       */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (PWM_MODULE_TYPE)
void CHIP_MuxPWM (PWM_MODULE_T pwm_module);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_MuxADC                                                                            */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  adc_module - The ADC module to be selected.                                            */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine selects the ADCx function to the corresponding pin.                       */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (ADC_MODULE_TYPE)
void CHIP_MuxADC (ADC_INPUT_T adc_module);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_MuxDAC                                                                            */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  dac_input - DAC Module number                                                          */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine selects the DACx outputs interface on multiplexed pin.                    */
/*                  The function should be called prior to any other DAC operation.                        */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (DAC_MODULE_TYPE)
void CHIP_MuxDAC (DAC_INPUT_T dac_input);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        CHIP_MuxSPI                                                                            */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  pwm_module - The PWM module to be selected.                                            */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine selects the PWMx function to the corresponding pin.                       */
/*---------------------------------------------------------------------------------------------------------*/
#if defined (SPI_MODULE_TYPE)
void CHIP_MuxSPI (SPI_MODULE_T spi_module);
#endif

#endif //__NPCE9MNX_IF_H__

