/*---------------------------------------------------------------------------------------------------------*/
/*  Nuvoton Technology Corporation confidential                                                            */
/*                                                                                                         */
/*  Copyright (c) 2010 by Nuvoton Technology Corporation                                                   */
/*  All rights reserved                                                                                    */
/*                                                                                                         */
/*<<<------------------------------------------------------------------------------------------------------*/
/* File Contents:                                                                                          */
/*   hfcg_drv.h                                                                                            */
/*            This file contains HFCG driver interface                                                     */
/*  Project:                                                                                               */
/*            SWC HAL                                                                                      */
/*---------------------------------------------------------------------------------------------------------*/

#ifndef HFCG_DRV_H
#define HFCG_DRV_H

#include "../hfcg_if.h"

/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                           TYPES & DEFINITIONS                                           */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/* Frequency multiplier values definition according to the requested FMCLK Clock Frequency                 */
/*---------------------------------------------------------------------------------------------------------*/
#define FMCLK_HFCGN    0x02
#if   (HFCG_FMCLK == (60 * _1MHz_))
#define FMCLK_HFCGMH   0x0E
#define FMCLK_HFCGML   0x4C
#elif (HFCG_FMCLK == (50 * _1MHz_))
#define FMCLK_HFCGMH   0x0B
#define FMCLK_HFCGML   0xEC
#elif (HFCG_FMCLK == (48 * _1MHz_))
#define FMCLK_HFCGMH   0x0B
#define FMCLK_HFCGML   0x72
#elif (HFCG_FMCLK == (40 * _1MHz_))
#define FMCLK_HFCGMH   0x09
#define FMCLK_HFCGML   0x89
#elif (HFCG_FMCLK == (33 * _1MHz_))
#define FMCLK_HFCGMH   0x07
#define FMCLK_HFCGML   0xDE
#elif (HFCG_FMCLK == (30 * _1MHz_))
#define FMCLK_HFCGMH   0x07
#define FMCLK_HFCGML   0x27
#elif (HFCG_FMCLK == (25 * _1MHz_))
#define FMCLK_HFCGMH   0x05
#define FMCLK_HFCGML   0xF6
#elif (HFCG_FMCLK == (15 * _1MHz_))
#define FMCLK_HFCGMH   0x03
#define FMCLK_HFCGML   0x63
#else
#error "Unsupported FMCLK Clock Frequency"
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Allowed Flash clock range                                                                               */
/*---------------------------------------------------------------------------------------------------------*/
#define FLASH_CLK_MAX       (60   *_1MHz_)
#define FLASH_CLK_MIN       (8250 * _1KHz_)

/*---------------------------------------------------------------------------------------------------------*/
/* Allowed Core clock range                                                                                */
/*---------------------------------------------------------------------------------------------------------*/
#define CORE_CLK_MAX        (60 *_1MHz_)
#define CORE_CLK_MIN        ( 4 *_1MHz_)


/*---------------------------------------------------------------------------------------------------------*/
/* HFCG Prescaler Register value definition according to the requested Flash and Core Clocks Frequency     */
/*lint -emacro(778, HFCGP_VAL)                                                                             */
/*---------------------------------------------------------------------------------------------------------*/
#define HFCGP_VAL   \
    ((((FLASH_DIVIDER) - 1) << 4) + ((CORE_DIVIDER)-1))

/*---------------------------------------------------------------------------------------------------------*/
/* Calculate flash prescaler divider according to the requested Flash Clock Frequency,                     */
/* verify the correct values range                                                                         */
/*---------------------------------------------------------------------------------------------------------*/
#if ((HFCG_FLASH_CLK > FLASH_CLK_MAX) || (HFCG_FLASH_CLK < FLASH_CLK_MIN))
#error "Flash Clock Frequency is out the range of 8.25 MHz to 50 MHz."
#endif

#define FLASH_DIVIDER       DIV_ROUND(HFCG_FMCLK, HFCG_FLASH_CLK)

/*---------------------------------------------------------------------------------------------------------*/
/* Calculate core prescaler divider according to the requested Core Clock Frequency,                       */
/* verify the correct values range                                                                         */
/*---------------------------------------------------------------------------------------------------------*/
#if ((HFCG_CORE_CLK > CORE_CLK_MAX) || (HFCG_CORE_CLK < CORE_CLK_MIN))
#error "Core Clock Frequency is out the range of 4 MHz to 60 MHz."
#endif

#define CORE_DIVIDER        DIV_ROUND(HFCG_FLASH_CLK, HFCG_CORE_CLK)

/*---------------------------------------------------------------------------------------------------------*/
/* Allow fast read in case Flash Clock Frequency is larger than 33MHz                                      */
/*---------------------------------------------------------------------------------------------------------*/
#if (HFCG_FLASH_CLK > (33*_1MHz_))
#define FLASH_FAST_READ     1
#else
#define FLASH_FAST_READ     0
#endif

#endif  /* HFCG_DRV_H */

