/*---------------------------------------------------------------------------------------------------------*/
/*  Nuvoton Technology Corporation confidential                                                            */
/*                                                                                                         */
/*  Copyright (c) 2010 by Nuvoton Technology Corporation                                                   */
/*  All rights reserved                                                                                    */
/*                                                                                                         */
/*<<<------------------------------------------------------------------------------------------------------*/
/* File Contents:                                                                                          */
/*   hfcg_if.h                                                                                             */
/*            This file contains High Frequency Clock Generator (HFCG) interface                           */
/*  Project:                                                                                               */
/*            SWC HAL                                                                                      */
/*---------------------------------------------------------------------------------------------------------*/
#ifndef _HFCG_IF_H
#define _HFCG_IF_H

/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                                 INCLUDES                                                */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

#include "../../Chips/chip.h"

#if defined HFCG_MODULE_TYPE
#include __MODULE_HEADER(hfcg, HFCG_MODULE_TYPE)
#endif

/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                           TYPES & DEFINITIONS                                           */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

#ifdef HFCG_CAPABILITY_APB_CLOCK
typedef enum
{
    HFCG_ABP_BUS_1 = 0,
    HFCG_ABP_BUS_2
} HFCG_ABP_BUS_T;
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Frequency multiplier values definition according to the requested FMCLK Clock Frequency                 */
/*---------------------------------------------------------------------------------------------------------*/
#define HFCG_FMCLK_HFCGN    FMCLK_HFCGN
#define HFCG_FMCLK_HFCGM    MAKE16(FMCLK_HFCGML, FMCLK_HFCGMH)
#define HFCG_FMCLK_HFCGMH   FMCLK_HFCGMH
#define HFCG_FMCLK_HFCGML   FMCLK_HFCGML
#define HFCG_HFCGP_VAL      HFCGP_VAL

/*---------------------------------------------------------------------------------------------------------*/
/* Boolean value, determing whether flash fast read is allowed                                             */
/*---------------------------------------------------------------------------------------------------------*/
#define HFCG_FLASH_FAST_READ    FLASH_FAST_READ


/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                           INTERFACE FUNCTIONS                                           */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_Config                                                                            */
/*                                                                                                         */
/* Parameters:      none                                                                                   */
/* Returns:         DEFS_STATUS_OK if no error occurred or error code otherwise                            */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine configures HFCG clock values to defaults set by <CHIP>.h file             */
/*---------------------------------------------------------------------------------------------------------*/
DEFS_STATUS HFCG_Config (void);

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_ConfigClocks                                                                      */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  freqMulM    - HFCG FMUL M parameter                                                    */
/*                  freqMulN    - HFCG FMUL N parameter                                                    */
/*                  flashDiv    - Flash divisor                                                            */
/*                  coreDiv     - Core divisor                                                             */
/*                                                                                                         */
/* Returns:         DEFS_STATUS_OK if no error occurred or error code otherwise                            */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine configures HFCG clocks                                                    */
/*---------------------------------------------------------------------------------------------------------*/
DEFS_STATUS HFCG_ConfigClocks(UINT16 freqMulM, UINT8 freqMulN, UINT8 coreDiv, UINT8 flashDiv);

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_Lock                                                                              */
/*                                                                                                         */
/* Parameters:      none                                                                                   */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine disables write access to all HFCG registers except HFCGP register.        */
/*                  Only reset clears this bit.                                                            */
/*---------------------------------------------------------------------------------------------------------*/
void HFCG_Lock (void);

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_SetFreqMultClkFreq                                                                */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  fmFreq - Frequency Multiplier reqeusted frequency                                      */
/*                                                                                                         */
/* Returns:         DEFS_STATUS_OK if no error occurred or error code otherwise                            */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine sets new Frequency Multiplier frequency                                   */
/*---------------------------------------------------------------------------------------------------------*/
DEFS_STATUS HFCG_SetFreqMultClkFreq(UINT32 fmFreq);

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_SetFlashClkFreq                                                                   */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  flashClk - Required Flash Clock                                                        */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine configures flash clock                                                    */
/*---------------------------------------------------------------------------------------------------------*/
DEFS_STATUS HFCG_SetFlashClkFreq (UINT32 flashClk);

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_SetCoreClkFreq                                                                    */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  coreClk - Required Core Clock                                                          */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine configures core clock                                                     */
/*---------------------------------------------------------------------------------------------------------*/
DEFS_STATUS HFCG_SetCoreClkFreq (UINT32 coreClk);

#ifdef HFCG_CAPABILITY_APB_CLOCK
/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_SetAPBClkFreq                                                                     */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  bus     - APB Bus number                                                               */
/*                  apbClk  - Required APB Clock                                                           */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine configures APB clock                                                      */
/*---------------------------------------------------------------------------------------------------------*/
DEFS_STATUS HFCG_SetAPBClkFreq (HFCG_ABP_BUS_T bus, UINT32 apbClk);
#endif

#ifdef HFCG_CAPABILITY_SIO_CLOCK
/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_SetSIOClkFreq                                                                     */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  sioClk  - Required Super I/O Clock                                                     */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine configures Super I/O clock                                                */
/*---------------------------------------------------------------------------------------------------------*/
DEFS_STATUS HFCG_SetSIOClkFreq (UINT32 sioClk);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_GetFreqMultClkFreq                                                                */
/*                                                                                                         */
/* Parameters:      none                                                                                   */
/* Returns:         Frequency multiplier clock (FMCLK) frequency, in 1 MHz resolution.                     */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine retrieves the frequency multiplier clock FMCLK, which is based on the     */
/*                  32 KHz Clock domain (32.768 KHz, low frequency (LFCLK) clock signal).                  */
/*                  FMCLK is rounded to 1 MHz resolution.                                                  */
/*---------------------------------------------------------------------------------------------------------*/
UINT32 HFCG_GetFreqMultClkFreq (void);

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_GetFlashClkFreq                                                                   */
/*                                                                                                         */
/* Parameters:      none                                                                                   */
/* Returns:         Flash clock (FCLK) frequency                                                           */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine retrieves the the flash clock (FCLK), which is based on the               */
/*                  high-frequency clock FMCLK.                                                            */
/*---------------------------------------------------------------------------------------------------------*/
UINT32 HFCG_GetFlashClkFreq (void);

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_GetCoreClkFreq                                                                    */
/*                                                                                                         */
/* Parameters:      none                                                                                   */
/* Returns:         Core clock (CLK) frequency                                                             */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine retrieves the core clock (CLK), which is based on the Flash clock FCLK.   */
/*---------------------------------------------------------------------------------------------------------*/
UINT32 HFCG_GetCoreClkFreq (void);

#ifdef HFCG_CAPABILITY_APB_CLOCK
/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_GetAPBClkFreq                                                                     */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  bus     - APB Bus number                                                               */
/*                                                                                                         */
/* Returns:         APB clock (APBCLK) frequency                                                           */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine retrieves the APB clock (APBCLK), which is based on CLK.                  */
/*---------------------------------------------------------------------------------------------------------*/
UINT32 HFCG_GetAPBClkFreq (HFCG_ABP_BUS_T bus);
#endif

#ifdef HFCG_CAPABILITY_SIO_CLOCK
/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_GetSIOClkFreq                                                                     */
/*                                                                                                         */
/* Parameters:      none                                                                                   */
/* Returns:         Super I/O clock (SIOCLK) frequency                                                     */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine retrieves the Super I/O clock (SIOCLK), which is based on FMCLK.          */
/*---------------------------------------------------------------------------------------------------------*/
UINT32 HFCG_GetSIOClkFreq (void);
#endif

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_DelayMicroSec_DefaultCoreClock                                                    */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  microSecDelay - Delay value in microseconds                                            */
/*                                                                                                         */
/* Returns:                                                                                                */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine performs delay based on Default Core Clock configuration from <CHIP>.h    */
/*---------------------------------------------------------------------------------------------------------*/
DEFS_STATUS HFCG_DelayMicroSec_DefaultCoreClock(UINT32 microSecDelay);

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_DelayMicroSec_CurrentCoreClock                                                    */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  microSecDelay - Delay value in miscroseconds                                           */
/*                                                                                                         */
/* Returns:                                                                                                */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine performs delay based on current core clock                                */
/*---------------------------------------------------------------------------------------------------------*/
DEFS_STATUS HFCG_DelayMicroSec_CurrentCoreClock(UINT32 microSecDelay);

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_DelayMicroSec_ProvidedCoreClock                                                   */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  microSecDelay   - Delay value in miscorseconds                                         */
/*                  coreClk         - Core clock value in Hz                                               */
/*                                                                                                         */
/* Returns:                                                                                                */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine performs delay based on provided core clock                               */
/*---------------------------------------------------------------------------------------------------------*/
DEFS_STATUS HFCG_DelayMicroSec_ProvidedCoreClock(UINT32 microSecDelay, UINT32 coreClk);

/*---------------------------------------------------------------------------------------------------------*/
/* Function:        HFCG_ConvertMicroSecToIterations                                                       */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  microSecDelay   - Delay in microseconds                                                */
/*                  coreClk         - Core clock value in Hz                                               */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine convert microsecond delay into loop iterations                            */
/*---------------------------------------------------------------------------------------------------------*/
UINT32 HFCG_ConvertMicroSecToIterations(UINT32 microSecDelay, UINT32 coreClk);

#endif  /* _HFCG_IF_H */

