/*---------------------------------------------------------------------------------------------------------*/
/*  Nuvoton Technology Corporation confidential                                                            */
/*                                                                                                         */
/*  Copyright (c) 2010 by Nuvoton Technology Corporation                                                   */
/*  All rights reserved                                                                                    */
/*                                                                                                         */
/*<<<------------------------------------------------------------------------------------------------------*/
/* File Contents:                                                                                          */
/*   icu_drv.c                                                                                             */
/*            This file contains Interrupt Control Unit (ICU) driver implementation                        */
/* Project:                                                                                                */
/*            SWC HAL                                                                                      */
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                                 INCLUDES                                                */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
#include "../../../Chips/chip.h"

#include "icu_drv.h"
#include "icu_regs.h"

#ifdef STATIC_DISPATCH_TABLE
#include "../../smb/smb_if.h"
#include "../../miwu/miwu_if.h"
#include "../../mft/mft_if.h"
#include "../../twd/twd_if.h"
#endif

/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                           TYPES & DEFINITIONS                                           */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/* Macro for defining TRAP routing functions                                                               */
/*---------------------------------------------------------------------------------------------------------*/
#define TRAP_ROUTER_FUNCTION(HANDLER, INT_NUM)                  \
void HANDLER ()                                                 \
{                                                               \
    (ICU_SW_DispatchTable[INT_NUM])(INT_NUM);                   \
}

/*---------------------------------------------------------------------------------------------------------*/
/* Hardware dispach table entry type                                                                       */
/*---------------------------------------------------------------------------------------------------------*/
typedef void (*INTERNAL_HANDLER_T)(void);



#ifndef EXTERNAL_DISPATCH_TABLE

/*---------------------------------------------------------------------------------------------------------*/
/* Use the icu driver internal dispatch table,                                                             */
/* otherwise assume that the table is already defined outside of this driver.                              */
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                       LOCAL FUNCTIONS DECLARATION                                       */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/* TRAP Handler                                                                                            */
/*---------------------------------------------------------------------------------------------------------*/
void ICU_TrapRouting_RES0_L (void);
void ICU_TrapRouting_NMI_L  (void);
void ICU_TrapRouting_RES2_L (void);
void ICU_TrapRouting_RES3_L (void);
void ICU_TrapRouting_RES4_L (void);
void ICU_TrapRouting_SVC_L  (void);
void ICU_TrapRouting_DVZ_L  (void);
void ICU_TrapRouting_FLG_L  (void);
void ICU_TrapRouting_BPT_L  (void);
void ICU_TrapRouting_TRC_L  (void);
void ICU_TrapRouting_UND_L  (void);
void ICU_TrapRouting_RES11_L(void);
void ICU_TrapRouting_IAD_L  (void);
void ICU_TrapRouting_RES13_L(void);
void ICU_TrapRouting_DBG_L  (void);
void ICU_TrapRouting_ISE_L  (void);


/*---------------------------------------------------------------------------------------------------------*/
/* INTERRUPTS Handler                                                                                      */
/*---------------------------------------------------------------------------------------------------------*/
static void ICU_Isr_L(void);

extern void vPortYield( void );
extern void vFreeRTOSInterruptHandler( void );

/*---------------------------------------------------------------------------------------------------------*/
/* NMI SW HANDLER                                                                                          */
/*---------------------------------------------------------------------------------------------------------*/
static void ICU_NMI_Handler_L(UINT16 int_num);

/*---------------------------------------------------------------------------------------------------------*/
/* DEFAULT SW HANDLER                                                                                      */
/*---------------------------------------------------------------------------------------------------------*/
static void ICU_Default_Handler_L (UINT16 int_num);


/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                          CONSTANTS & VARIABLES                                          */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------------------------*/
/* Dispatch Table                                                                                          */
/*---------------------------------------------------------------------------------------------------------*/
static const INTERNAL_HANDLER_T ICU_DispatchTable[ICU_TABLE_SIZE] =
{
    /* Traps */
    /*  0 */    ICU_TrapRouting_RES0_L,
    /*  1 */    ICU_TrapRouting_NMI_L,
    /*  2 */    ICU_TrapRouting_RES2_L,
    /*  3 */    ICU_TrapRouting_RES3_L,
    /*  4 */    ICU_TrapRouting_RES4_L,
    /*  5 */    vPortYield,
    /*  6 */    ICU_TrapRouting_DVZ_L,
    /*  7 */    ICU_TrapRouting_FLG_L,
    /*  8 */    ICU_TrapRouting_BPT_L,
    /*  9 */    ICU_TrapRouting_TRC_L,
    /* 10 */    ICU_TrapRouting_UND_L,
    /* 11 */    ICU_TrapRouting_RES11_L,
    /* 12 */    ICU_TrapRouting_IAD_L,
    /* 13 */    ICU_TrapRouting_RES13_L,
    /* 14 */    ICU_TrapRouting_DBG_L,
    /* 15 */    ICU_TrapRouting_ISE_L,
    /* Interrupts */
    /*  0 */    vFreeRTOSInterruptHandler,
    /*  1 */    vFreeRTOSInterruptHandler,
    /*  2 */    vFreeRTOSInterruptHandler,
    /*  3 */    vFreeRTOSInterruptHandler,
    /*  4 */    vFreeRTOSInterruptHandler,
    /*  5 */    vFreeRTOSInterruptHandler,
    /*  6 */    vFreeRTOSInterruptHandler,
    /*  7 */    vFreeRTOSInterruptHandler,
    /*  8 */    vFreeRTOSInterruptHandler,
    /*  9 */    vFreeRTOSInterruptHandler,
    /* 10 */    vFreeRTOSInterruptHandler,
    /* 11 */    vFreeRTOSInterruptHandler,
    /* 12 */    vFreeRTOSInterruptHandler,
    /* 13 */    vFreeRTOSInterruptHandler,
    /* 14 */    vFreeRTOSInterruptHandler,
    /* 15 */    vFreeRTOSInterruptHandler,
    /* 16 */    vFreeRTOSInterruptHandler,
    /* 17 */    vFreeRTOSInterruptHandler,
    /* 18 */    vFreeRTOSInterruptHandler,
    /* 19 */    vFreeRTOSInterruptHandler,
    /* 20 */    vFreeRTOSInterruptHandler,
    /* 21 */    vFreeRTOSInterruptHandler,
    /* 22 */    vFreeRTOSInterruptHandler,
    /* 23 */    vFreeRTOSInterruptHandler,
    /* 24 */    vFreeRTOSInterruptHandler,
    /* 25 */    vFreeRTOSInterruptHandler,
    /* 26 */    vFreeRTOSInterruptHandler,
    /* 27 */    vFreeRTOSInterruptHandler,
    /* 28 */    vFreeRTOSInterruptHandler,
    /* 29 */    vFreeRTOSInterruptHandler,
    /* 30 */    vFreeRTOSInterruptHandler,
    /* 31 */    vFreeRTOSInterruptHandler,
};

#ifndef STATIC_DISPATCH_TABLE
static HANDLER_T ICU_SW_DispatchTable[ICU_TABLE_SIZE];
#else
const static HANDLER_T ICU_SW_DispatchTable[ICU_TABLE_SIZE];
{
    /* Traps */
    /*  0 */    ICU_Default_Handler_L,
    /*  1 */    ICU_NMI_Handler_L,
    /*  2 */    ICU_Default_Handler_L,
    /*  3 */    ICU_Default_Handler_L,
    /*  4 */    ICU_Default_Handler_L,
    /*  5 */    ICU_Default_Handler_L,
    /*  6 */    ICU_Default_Handler_L,
    /*  7 */    ICU_Default_Handler_L,
    /*  8 */    ICU_Default_Handler_L,
    /*  9 */    ICU_Default_Handler_L,
    /* 10 */    ICU_Default_Handler_L,
    /* 11 */    ICU_Default_Handler_L,
    /* 12 */    ICU_Default_Handler_L,
    /* 13 */    ICU_Default_Handler_L,
    /* 14 */    ICU_Default_Handler_L,
    /* 15 */    ICU_Default_Handler_L,
    /* Interrupts */
    /*  0 */    ICU_Default_Handler_L,
    /*  1 */    ICU_Default_Handler_L,
    /*  2 */    ICU_Default_Handler_L,
    /*  3 */    ICU_Default_Handler_L,
    /*  4 */    SMB_IntHandler,
    /*  5 */    SMB_IntHandler,
    /*  6 */    ICU_Default_Handler_L,
    /*  7 */    MIWU_IntHandler,
    /*  8 */    ICU_Default_Handler_L,
    /*  9 */    MFT_IntHandler,
    /* 10 */    ICU_Default_Handler_L,
    /* 11 */    MIWU_IntHandler,
    /* 12 */    ICU_Default_Handler_L,
    /* 13 */    SMB_IntHandler,
    /* 14 */    SMB_IntHandler,
    /* 15 */    ICU_Default_Handler_L,
    /* 16 */    MIWU_IntHandler,
    /* 17 */    ICU_Default_Handler_L,
    /* 18 */    ICU_Default_Handler_L,
    /* 19 */    ICU_Default_Handler_L,
    /* 20 */    ICU_Default_Handler_L,
    /* 21 */    ICU_Default_Handler_L,
    /* 22 */    ICU_Default_Handler_L,
    /* 23 */    MIWU_IntHandler,
    /* 24 */    ICU_Default_Handler_L,
    /* 25 */    ICU_Default_Handler_L,
    /* 26 */    ICU_Default_Handler_L,
    /* 27 */    ICU_Default_Handler_L,
    /* 28 */    ICU_Default_Handler_L,
    /* 29 */    ICU_Default_Handler_L,
    /* 30 */    ICU_Default_Handler_L,
    /* 31 */    TWD_TimerHandler,
};
#endif  /* STATIC_DISPATCH_TABLE */


/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                           INTERFACE FUNCTIONS                                           */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/


/*---------------------------------------------------------------------------------------------------------*/
/* Function:        ICU_InitTab                                                                            */
/*                                                                                                         */
/* Parameters:      none                                                                                   */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine initializes the dispatch-table (interrupt-vector).                        */
/*---------------------------------------------------------------------------------------------------------*/
void ICU_InitTab (void)
{
    /*-----------------------------------------------------------------------------------------------------*/
    /* PSR register is read into this variable                                                             */
    /*-----------------------------------------------------------------------------------------------------*/
    UINT    saved_psr = 0;
#ifndef STATIC_DISPATCH_TABLE
    UINT    int_no;
#endif

    INTERRUPTS_SAVE_DISABLE(saved_psr);

#ifndef STATIC_DISPATCH_TABLE
    /*-----------------------------------------------------------------------------------------------------*/
    /* Initial Interrupts & Traps                                                                          */
    /*-----------------------------------------------------------------------------------------------------*/
    for (int_no = 0; int_no < ICU_TABLE_SIZE; int_no++)
    {
        ICU_SW_DispatchTable[int_no] = ICU_Default_Handler_L;
    }

    ICU_SW_DispatchTable[ICU_TRAP_NMI]   = ICU_NMI_Handler_L;

#endif  /* STATIC_DISPATCH_TABLE */

    INTERRUPTS_SET_VECTOR_TABLE(ICU_DispatchTable);

    INTERRUPTS_RESTORE(saved_psr);
}
#endif /* EXTERNAL_DISPATCH_TABLE */



/*---------------------------------------------------------------------------------------------------------*/
/* Function:        ICU_Init                                                                               */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  inttable - TRUE: Install null_handlers for all interrupts                              */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:    This function only sets the Global Interrupt Enable (I bit in PSR register).           */
/*                  The Local Interrupt Enable (E bit in PSR register) remains cleared.                    */
/*                  The upper-layer should call ENABLE_INTERRUPTS to set the E bit when desired.           */
/* Description:                                                                                            */
/*                  This routine:                                                                          */
/*                  1. Masks all interrupts.                                                               */
/*                  2. Clears all pending interrupts.                                                      */
/*                  3. if inttable is TRUE: Installs the default interrupt dispatch-table                  */
/*                     (null_handlers for all interrupts).                                                 */
/*---------------------------------------------------------------------------------------------------------*/
void ICU_Init (BOOLEAN inttable)
{
    /*-----------------------------------------------------------------------------------------------------*/
    /* Disable Interrupts                                                                                  */
    /*-----------------------------------------------------------------------------------------------------*/
    DISABLE_INTERRUPTS();

    /*-----------------------------------------------------------------------------------------------------*/
    /* Mask All Interrupts                                                                                 */
    /*-----------------------------------------------------------------------------------------------------*/
    REG_WRITE(IENAM0, 0);
    REG_WRITE(IENAM1, 0);

    /*-----------------------------------------------------------------------------------------------------*/
    /* Clear all pending interrupts (affects edge-triggered only)                                          */
    /*-----------------------------------------------------------------------------------------------------*/
    REG_WRITE(IECLR0, 0xFFFF);
    REG_WRITE(IECLR1, 0xFFFF);

#ifndef EXTERNAL_DISPATCH_TABLE
    if (inttable)
    {
        ICU_InitTab();
    }
#endif
    /*-----------------------------------------------------------------------------------------------------*/
    /* Note that at this point interrupts are still disabled, since the E bit in PSR register is cleared.  */
    /* The upper-layer should call ENABLE_INTERRUPTS to set the E bit when desired                         */
    /*-----------------------------------------------------------------------------------------------------*/
}



#ifndef STATIC_DISPATCH_TABLE
/*---------------------------------------------------------------------------------------------------------*/
/* Function:        ICU_InstallTrap                                                                        */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  trap_no - number of trap for which the handler should be installed.                    */
/*                  proc   - trap handler procedure to be installed.                                       */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine installs the provided trap handler in the dispatch table.                 */
/*                  The function is used to install or change the trap handler when the                    */
/*                  dispatch-table is placed in RAM.                                                       */
/*---------------------------------------------------------------------------------------------------------*/
void ICU_InstallTrap (
    ICU_TRAP_SRC_T  trap_no,
    HANDLER_T       proc
)
{
    ASSERT(trap_no < ICU_TRAP_NUM);

    ATOMIC_OP((ICU_SW_DispatchTable[trap_no] = proc));
}



/*---------------------------------------------------------------------------------------------------------*/
/* Function:        ICU_InstallHandler                                                                     */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  int_no - number of interrupt for which the handler should be installed.                */
/*                  proc   - interrupt handler procedure to be installed.                                  */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine installs the provided interrupt handler in the dispatch table.            */
/*                  The function is used to install or change the interrupt handler when the               */
/*                  dispatch-table is placed in RAM.                                                       */
/*---------------------------------------------------------------------------------------------------------*/
void ICU_InstallHandler (
    ICU_INT_SRC_T   int_no,
    HANDLER_T       proc
)
{
    ASSERT(int_no < ICU_INTERRUPT_NUM);

    ATOMIC_OP((ICU_SW_DispatchTable[ICU_INT_BASE + int_no] = proc));
}
#endif  /* STATIC_DISPATCH_TABLE */



/*---------------------------------------------------------------------------------------------------------*/
/* Function:        ICU_EnableInt                                                                          */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  int_no  - interrupt number                                                             */
/*                  enable  - TRUE to enable interrupt, FALSE to disable                                   */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine enables/disables interrupt number int_no.                                 */
/*---------------------------------------------------------------------------------------------------------*/
void ICU_EnableInt (ICU_INT_SRC_T int_no, BOOLEAN enable)
{
    ASSERT(int_no < ICU_INTERRUPT_NUM);

    if (enable)
    {
        /*-------------------------------------------------------------------------------------------------*/
        /* Enable interrupt                                                                                */
        /*-------------------------------------------------------------------------------------------------*/
        if (int_no <= 15)
        {
            SET_REG_BIT(IENAM0, int_no);
        }
        else
        {
            SET_REG_BIT(IENAM1, int_no - 16);
        }
    }
    else
    {
        /*-------------------------------------------------------------------------------------------------*/
        /* Disable interrupt                                                                               */
        /*-------------------------------------------------------------------------------------------------*/
        if (int_no <= 15)
        {
            CLEAR_REG_BIT(IENAM0, int_no);
        }
        else
        {
            CLEAR_REG_BIT(IENAM1, int_no - 16);
        }
    }
}


/*---------------------------------------------------------------------------------------------------------*/
/* Function:        ICU_IntEnabled                                                                         */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  int_no    - Number of interrupt to check if enabled                                    */
/*                                                                                                         */
/* Returns:                                                                                                */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine checks if given interrupt is enabled                                      */
/*---------------------------------------------------------------------------------------------------------*/
BOOLEAN ICU_IntEnabled(ICU_INT_SRC_T int_no)
{
    if (int_no <= 15)
    {
        return (BOOLEAN)READ_REG_BIT(IENAM0, int_no);
    }
    else
    {
        return (BOOLEAN)READ_REG_BIT(IENAM1, int_no - 16);
    }
}


/*---------------------------------------------------------------------------------------------------------*/
/* Function:        ICU_ClearInt                                                                           */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  int_no - interrupt number                                                              */
/*                                                                                                         */
/* Returns:         none                                                                                   */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine clears interrupt number int_no.                                           */
/*---------------------------------------------------------------------------------------------------------*/
void ICU_ClearInt (ICU_INT_SRC_T int_no)
{
    ASSERT(int_no < ICU_INTERRUPT_NUM);

    if (int_no <= 15)
    {
        REG_WRITE(IECLR0, 1 << int_no);
    }
    else
    {
        REG_WRITE(IECLR1, 1 << (int_no - 16));
    }
}



/*---------------------------------------------------------------------------------------------------------*/
/* Function:        ICU_PendingInt                                                                         */
/*                                                                                                         */
/* Parameters:                                                                                             */
/*                  int_no - interrupt number                                                              */
/*                                                                                                         */
/* Returns:         interrupts status                                                                      */
/* Side effects:                                                                                           */
/* Description:                                                                                            */
/*                  This routine returns TRUE if given int_no interrupt is pending                         */
/*---------------------------------------------------------------------------------------------------------*/
BOOLEAN ICU_PendingInt (ICU_INT_SRC_T int_no)
{
    UINT32 pending = MAKE32(REG_READ(ISTAT0), REG_READ(ISTAT1));

    return (BOOLEAN)(READ_VAR_BIT(pending, int_no));
}


/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
/*                                             LOCAL FUNCTIONS                                             */
/*---------------------------------------------------------------------------------------------------------*/
/*---------------------------------------------------------------------------------------------------------*/
#pragma interrupt (ICU_Isr_L)
void ICU_Isr_L(void)
{
    /*-----------------------------------------------------------------------------------------------------*/
    /* Retrieve ISR vector number                                                                          */
    /*-----------------------------------------------------------------------------------------------------*/
    UINT16 vector = READ_REG_FIELD(IDBG, IDBG_LINTVECT);

    /*-----------------------------------------------------------------------------------------------------*/
    /* Clear the pending interrupt                                                                         */
    /*-----------------------------------------------------------------------------------------------------*/
    ICU_ClearInt((ICU_INT_SRC_T)(vector - ICU_TRAP_NUM));

    /*-----------------------------------------------------------------------------------------------------*/
    /* Invoke appropriate vector                                                                           */
    /*-----------------------------------------------------------------------------------------------------*/
    (ICU_SW_DispatchTable[vector])(vector - ICU_TRAP_NUM);
}




/*---------------------------------------------------------------------------------------------------------*/
/* TRAP Routing functions                                                                                  */
/*---------------------------------------------------------------------------------------------------------*/
#pragma interrupt (ICU_TrapRouting_RES0_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_RES0_L, 0)

#pragma interrupt (ICU_TrapRouting_NMI_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_NMI_L, 1)

#pragma interrupt (ICU_TrapRouting_RES2_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_RES2_L, 2)

#pragma interrupt (ICU_TrapRouting_RES3_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_RES3_L, 3)

#pragma interrupt (ICU_TrapRouting_RES4_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_RES4_L, 4)

#pragma interrupt (ICU_TrapRouting_SVC_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_SVC_L, 5)

#pragma interrupt (ICU_TrapRouting_DVZ_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_DVZ_L, 6)

#pragma interrupt (ICU_TrapRouting_FLG_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_FLG_L, 7)

#pragma interrupt (ICU_TrapRouting_BPT_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_BPT_L, 8)

#pragma interrupt (ICU_TrapRouting_TRC_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_TRC_L, 9)

#pragma interrupt (ICU_TrapRouting_UND_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_UND_L, 10)

#pragma interrupt (ICU_TrapRouting_RES11_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_RES11_L, 11)

#pragma interrupt (ICU_TrapRouting_IAD_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_IAD_L, 12)

#pragma interrupt (ICU_TrapRouting_RES13_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_RES13_L, 13)

#pragma interrupt (ICU_TrapRouting_DBG_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_DBG_L, 14)

#pragma interrupt (ICU_TrapRouting_ISE_L)
TRAP_ROUTER_FUNCTION(ICU_TrapRouting_ISE_L, 15)


/*---------------------------------------------------------------------------------------------------------*/
/* NMI SW HANDLER                                                                                          */
/*---------------------------------------------------------------------------------------------------------*/
void ICU_NMI_Handler_L(UINT16 int_num)
{
    (void)REG_READ(NMISTAT);

    ASSERT(FALSE);
}

/*---------------------------------------------------------------------------------------------------------*/
/* DEFAULT SW HANDLER                                                                                      */
/*---------------------------------------------------------------------------------------------------------*/
void ICU_Default_Handler_L (UINT16 int_num)
{
    ASSERT(FALSE);
}

